"""Top-level package for Refactor Guide."""

__author__ = """Qin Yu"""
__email__ = 'qinyusuain@gmail.com'
__version__ = '0.1.3'

import refactorguide.desgin as desgin

desgin.init()
